AnomalyInstance class

The specific duration in which the metric is flagged as anomalous.

Constructors

AnomalyInstance({required String id, required DateTime startTime, DateTime? endTime, UserFeedback? userFeedback})
AnomalyInstance.fromJson(Map<String, dynamic> json)
factory

Properties

endTime → DateTime?
The end time of the period during which the metric is flagged as anomalous. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The universally unique identifier (UUID) of an instance of an anomaly in a metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
The start time of the period during which the metric is flagged as anomalous. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
userFeedback → UserFeedback?
Feedback type on a specific instance of anomaly submitted by the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited