Channel class

Notification medium for users to get alerted for events that occur in application profile. We support SNS topic as a notification channel.

Constructors

Channel({required List<EventPublisher> eventPublishers, required String uri, String? id})
Channel.fromJson(Map<String, dynamic> json)
factory

Properties

eventPublishers → List<EventPublisher>
List of publishers for different type of events that may be detected in an application from the profile. Anomaly detection is the only event publisher in Profiler.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Unique identifier for each Channel in the notification configuration of a Profiling Group. A random UUID for channelId is used when adding a channel to the notification configuration if not specified in the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
Unique arn of the resource to be used for notifications. We support a valid SNS topic arn as a channel uri.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited