ConfigureAgentResponse class

The structure representing the configureAgentResponse.

Constructors

ConfigureAgentResponse({required AgentConfiguration configuration})

Properties

configuration → AgentConfiguration
An AgentConfiguration object that specifies if an agent profiles or not and for how long to return profiling data.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited