FrameMetric class

The frame name, metric type, and thread states. These are used to derive the value of the metric for the frame.

Constructors

FrameMetric({required String frameName, required List<String> threadStates, required MetricType type})
FrameMetric.fromJson(Map<String, dynamic> json)
factory

Properties

frameName → String
Name of the method common across the multiple occurrences of a frame in an application profile.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadStates → List<String>
List of application runtime thread states used to get the counts for a frame a derive a metric value.
final
type → MetricType
A type of aggregation that specifies how a metric for a frame is analyzed. The supported value AggregatedRelativeTotalTime is an aggregation of the metric value for one frame that is calculated across the occurrences of all frames in a profile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited