GetProfileResponse class

The structure representing the getProfileResponse.

Constructors

GetProfileResponse({required String contentType, required Uint8List profile, String? contentEncoding})

Properties

contentEncoding → String?
The content encoding of the profile.
final
contentType → String
The content type of the profile in the payload. It is either application/json or the default application/x-amzn-ion.
final
hashCode → int
The hash code for this object.
no setterinherited
profile → Uint8List
Information about the profile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited