GetRecommendationsResponse class

The structure representing the GetRecommendationsResponse.

Constructors

GetRecommendationsResponse({required List<Anomaly> anomalies, required DateTime profileEndTime, required DateTime profileStartTime, required String profilingGroupName, required List<Recommendation> recommendations})
GetRecommendationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

anomalies → List<Anomaly>
The list of anomalies that the analysis has found for this profile.
final
hashCode → int
The hash code for this object.
no setterinherited
profileEndTime → DateTime
The end time of the profile the analysis data is about. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
profileStartTime → DateTime
The start time of the profile the analysis data is about. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
profilingGroupName → String
The name of the profiling group the analysis data is about.
final
recommendations → List<Recommendation>
The list of recommendations that the analysis found for this profile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited