ListProfileTimesResponse class

The structure representing the listProfileTimesResponse.

Constructors

ListProfileTimesResponse({required List<ProfileTime> profileTimes, String? nextToken})
ListProfileTimesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The nextToken value to include in a future ListProfileTimes request. When the results of a ListProfileTimes request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
final
profileTimes → List<ProfileTime>
The list of start times of the available profiles for the aggregation period in the specified time range.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited