NotificationConfiguration class

The configuration for notifications stored for each profiling group. This includes up to to two channels and a list of event publishers associated with each channel.

Constructors

NotificationConfiguration({List<Channel>? channels})
NotificationConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

channels → List<Channel>?
List of up to two channels to be used for sending notifications for events detected from the application profile.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited