Pattern class

A set of rules used to make a recommendation during an analysis.

Constructors

Pattern({List<String>? countersToAggregate, String? description, String? id, String? name, String? resolutionSteps, List<List<String>>? targetFrames, double? thresholdPercent})
Pattern.fromJson(Map<String, dynamic> json)
factory

Properties

countersToAggregate → List<String>?
A list of the different counters used to determine if there is a match.
final
description → String?
The description of the recommendation. This explains a potential inefficiency in a profiled application.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The universally unique identifier (UUID) of this pattern.
final
name → String?
The name for this pattern.
final
resolutionSteps → String?
A string that contains the steps recommended to address the potential inefficiency.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFrames → List<List<String>>?
A list of frame names that were searched during the analysis that generated a recommendation.
final
thresholdPercent → double?
The percentage of time an application spends in one method that triggers a recommendation. The percentage of time is the same as the percentage of the total gathered sample counts during analysis.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited