ProfilingGroupDescription class

Contains information about a profiling group.

Constructors

ProfilingGroupDescription({AgentOrchestrationConfig? agentOrchestrationConfig, String? arn, ComputePlatform? computePlatform, DateTime? createdAt, String? name, ProfilingStatus? profilingStatus, Map<String, String>? tags, DateTime? updatedAt})
ProfilingGroupDescription.fromJson(Map<String, dynamic> json)
factory

Properties

agentOrchestrationConfig → AgentOrchestrationConfig?
An AgentOrchestrationConfig object that indicates if the profiling group is enabled for profiled or not.
final
arn → String?
The Amazon Resource Name (ARN) identifying the profiling group resource.
final
computePlatform → ComputePlatform?
The compute platform of the profiling group. If it is set to AWSLambda, then the profiled application runs on AWS Lambda. If it is set to Default, then the profiled application runs on a compute platform that is not AWS Lambda, such an Amazon EC2 instance, an on-premises server, or a different platform. The default is Default.
final
createdAt → DateTime?
The time when the profiling group was created. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the profiling group.
final
profilingStatus → ProfilingStatus?
A ProfilingStatus object that includes information about the last time a profile agent pinged back, the last time a profile was received, and the aggregation period and start time for the most recent aggregated profile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
A list of the tags that belong to this profiling group.
final
updatedAt → DateTime?
The date and time when the profiling group was last updated. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited