ProfilingStatus class

Profiling status includes information about the last time a profile agent pinged back, the last time a profile was received, and the aggregation period and start time for the most recent aggregated profile.

Constructors

ProfilingStatus({DateTime? latestAgentOrchestratedAt, DateTime? latestAgentProfileReportedAt, AggregatedProfileTime? latestAggregatedProfile})
ProfilingStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latestAgentOrchestratedAt → DateTime?
The date and time when the profiling agent most recently pinged back. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
latestAgentProfileReportedAt → DateTime?
The date and time when the most recent profile was received. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
latestAggregatedProfile → AggregatedProfileTime?
An AggregatedProfileTime object that contains the aggregation period and start time for an aggregated profile.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited