Recommendation class

A potential improvement that was found from analyzing the profiling data.

Constructors

Recommendation({required int allMatchesCount, required double allMatchesSum, required DateTime endTime, required Pattern pattern, required DateTime startTime, required List<Match> topMatches})
Recommendation.fromJson(Map<String, dynamic> json)
factory

Properties

allMatchesCount → int
How many different places in the profile graph triggered a match.
final
allMatchesSum → double
How much of the total sample count is potentially affected.
final
endTime → DateTime
End time of the profile that was used by this analysis. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
hashCode → int
The hash code for this object.
no setterinherited
pattern → Pattern
The pattern that analysis recognized in the profile to make this recommendation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
The start time of the profile that was used by this analysis. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.
final
topMatches → List<Match>
List of the matches with most impact.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited