UpdateProfilingGroupResponse class

The structure representing the updateProfilingGroupResponse.

Constructors

UpdateProfilingGroupResponse({required ProfilingGroupDescription profilingGroup})

Properties

hashCode → int
The hash code for this object.
no setterinherited
profilingGroup → ProfilingGroupDescription
A ProfilingGroupDescription that contains information about the returned updated profiling group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited